aboutsummaryrefslogtreecommitdiff
path: root/src/ppu/ppu.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ppu/ppu.h')
-rw-r--r--src/ppu/ppu.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/ppu/ppu.h b/src/ppu/ppu.h
index 75d97c1..3210418 100644
--- a/src/ppu/ppu.h
+++ b/src/ppu/ppu.h
@@ -8,13 +8,15 @@ void hh_ppu_vblank_interrupt();
void hh_ppu_init();
/** @brief deinitialize ppu interface */
void hh_ppu_deinit();
+/** @brief flush ppu buffer */
+void hh_ppu_flush();
/** @brief update single foreground sprite */
void hh_ppu_update_foreground(unsigned index, hh_s_ppu_loc_fam_entry e);
/** @brief update single background sprite */
void hh_ppu_update_background(unsigned index, hh_s_ppu_loc_bam_entry e);
-/** @brief update aux register */
-void hh_ppu_update_aux(hh_s_ppu_loc_aux aux);
+/** @brief update background shift */
+void hh_ppu_update_background_pos(uint16_t shift_x, uint16_t shift_y);
/** @brief update single sprite */
void hh_ppu_update_sprite(unsigned tilemap_index, const hh_s_ppu_loc_sprite sprite);
/** @brief update entire palette table */